"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.generateJestCommand = exports.generateCoverageSummary = exports.createComment = exports.getIssueNumber = exports.generateComment = exports.getCoveragePercent = exports.execCommand = exports.summaryFormatter = exports.stringFormatter = void 0;
const exec_1 = require("@actions/exec");
const github_1 = require("@actions/github");
const core_1 = require("@actions/core");
const findTableStart = (search, array) => {
    const index = array.findIndex((line) => line.startsWith(search), search);
    return (index > 0 ? index : 1);
};
const stringFormatter = (input) => input.join('\n');
exports.stringFormatter = stringFormatter;
const summaryFormatter = (input) => exports.stringFormatter(input.slice(findTableStart('File', input), input.length - 1));
exports.summaryFormatter = summaryFormatter;
const execCommand = (command, formatter = exports.stringFormatter) => __awaiter(void 0, void 0, void 0, function* () {
    const workingDir = core_1.getInput('working-directory');
    const output = [];
    const options = {
        silent: true,
        listeners: {
            stdline: (data) => {
                output.push(data);
            }
        },
        cwd: `./${workingDir}`
    };
    try {
        yield exec_1.exec(command, [], options);
        return Promise.resolve(formatter(output));
    }
    catch (e) {
        core_1.error(`ExecCommand error: ${e}`);
        return Promise.reject(e);
    }
});
exports.execCommand = execCommand;
const getCoveragePercent = () => __awaiter(void 0, void 0, void 0, function* () {
    const percent = yield exports.execCommand('npx coverage-percentage ./coverage/lcov.info --lcov');
    return Number(parseFloat(percent).toFixed(2));
});
exports.getCoveragePercent = getCoveragePercent;
const generateComment = (percent, summary) => `<p>Total Coverage: <code>${percent} %</code></p>
<details><summary>Coverage report</summary>

${summary}

</details>`;
exports.generateComment = generateComment;
const isPreviousTotalCoverageComment = comment => {
    comment.user &&
        comment.body &&
        comment.user.login === 'github-actions[bot]' &&
        comment.body.includes('Total Coverage');
};
const deleteComment = octokit => comment => octokit.issues.deleteComment(Object.assign(Object.assign({}, github_1.context.repo), { comment_id: comment.id }));
const deletePreviousComments = (issueNumber) => __awaiter(void 0, void 0, void 0, function* () {
    const octokit = github_1.getOctokit(core_1.getInput('github-token'));
    const { data: comments } = yield octokit.issues.listComments(Object.assign(Object.assign({}, github_1.context.repo), { per_page: 100, issue_number: issueNumber }));
    return Promise.all(comments
        .filter(isPreviousTotalCoverageComment)
        .map(deleteComment(octokit)));
});
const getIssueNumber = (payload) => {
    var _a, _b;
    return ((_a = payload === null || payload === void 0 ? void 0 : payload.pull_request) === null || _a === void 0 ? void 0 : _a.number) || ((_b = payload === null || payload === void 0 ? void 0 : payload.issue) === null || _b === void 0 ? void 0 : _b.number);
};
exports.getIssueNumber = getIssueNumber;
const createComment = (comment) => __awaiter(void 0, void 0, void 0, function* () {
    const octokit = github_1.getOctokit(core_1.getInput('github-token'));
    const issueNumber = exports.getIssueNumber(github_1.context.payload);
    const deletePrev = getBooleanInput('delete-previous');
    if (!issueNumber) {
        core_1.warning('Issue number not found. Impossible to create a comment');
        return;
    }
    if (deletePrev) {
        yield deletePreviousComments(issueNumber);
    }
    yield octokit.issues.createComment({
        repo: github_1.context.repo.repo,
        owner: github_1.context.repo.owner,
        body: comment,
        issue_number: issueNumber
    });
});
exports.createComment = createComment;
const generateCoverageSummary = (jestCommand) => __awaiter(void 0, void 0, void 0, function* () { return yield exports.execCommand(jestCommand, exports.summaryFormatter); });
exports.generateCoverageSummary = generateCoverageSummary;
const getBooleanInput = (input) => {
    switch (core_1.getInput(input)) {
        case 'true':
            return true;
        case 'false':
            return false;
        default:
            return undefined;
    }
};
const generateChangeSinceParam = (baseCommand) => {
    var _a, _b;
    const param = getBooleanInput('only-changes');
    if (!param) {
        return '';
    }
    if (baseCommand.includes('changeSince')) {
        return '';
    }
    if ((_a = github_1.context.payload.pull_request) === null || _a === void 0 ? void 0 : _a.base) {
        return `--changeSince=${(_b = github_1.context.payload.pull_request) === null || _b === void 0 ? void 0 : _b.base.ref}`;
    }
    return '';
};
const generateJestCommand = () => {
    const baseCommand = core_1.getInput('jest-command');
    const changeSinceParam = generateChangeSinceParam(baseCommand);
    return `${baseCommand} ${changeSinceParam}`;
};
exports.generateJestCommand = generateJestCommand;
